// TimedBars.cpp : Defines the class behaviors for the application.
//

#include "stdafx.h"
#include <cassert>
#include "Helper.h"

const CString CHelper::m_N_A = _T("N/A");
const CString CHelper::DateFormat = _T("dd/MM/yyyy HH:mm");

void CHelper::SetComboBoxItem(
                        CComboBox& comboBoxCtrl,
                        DWORD_PTR itemData)
{
   for (int i = 0; i < comboBoxCtrl.GetCount(); ++i)
   {
      if (comboBoxCtrl.GetItemData(i) == itemData)
      {
         comboBoxCtrl.SetCurSel(i);
         return;
      }
   }

   assert(!"Invalid item data");
}

int CHelper::CompareDates(
                        const COleDateTime& date1,
                        const COleDateTime& date2)
{
   // Check if dates are equal (seconds are ignored)
   if (date1.GetYear() == date2.GetYear() && date1.GetMonth() == date2.GetMonth() &&
      date1.GetDay() == date2.GetDay() && date1.GetHour() == date2.GetHour() &&
      date1.GetMinute() == date2.GetMinute())
   {
      return 0;
   }

   return (date1 < date2 ? -1 : 1);
}

CString CHelper::ConnectionStatusToString(
                        eConnectionStatus connectionStatus)
{
   CString connectionStatusStr;

   switch (connectionStatus)
   {
   case csConnectionUp:
      connectionStatusStr = _T("Connection Up");
      break;
   case csConnectionDown:
      connectionStatusStr = _T("Connection Down");
      break;
   case csConnectionDelayed:
      connectionStatusStr = _T("Connection Delayed");
      break;
   default:
      assert(!"Unknown connection status");
   }

   return connectionStatusStr;
}

CString CHelper::RequestStatusToString(
                        eRequestStatus requestStatus)
{
   CString requestStatusStr;

   switch (requestStatus)
   {
   case rsInProgress:
      requestStatusStr = _T("InProgress");
      break;
   case rsSuccess:
      requestStatusStr = _T("Success");
      break;
   case rsCanceled:
      requestStatusStr = _T("Canceled");
      break;
   case rsFailed:
      requestStatusStr = _T("Failed");
      break;
   default:
      assert(!"Unknown request status");
   }

   return requestStatusStr;
}

CString CHelper::HistoricalPeriodToString(
                        eHistoricalPeriod historicalPeriod)
{
   CString historicalPeriodStr;

   switch (historicalPeriod)
   {
   case hpUndefined:
      historicalPeriodStr = _T("Undefined");
      break;
   case hpDaily:
      historicalPeriodStr = _T("Daily");
      break;
   case hpWeekly:
      historicalPeriodStr = _T("Weekly");
      break;
   case hpMonthly:
      historicalPeriodStr = _T("Monthly");
      break;
   case hpQuarterly:
      historicalPeriodStr = _T("Quarterly");
      break;
   case hpSemiannual:
      historicalPeriodStr = _T("Semiannual");
      break;
   case hpYearly:
      historicalPeriodStr = _T("Yearly");
      break;
   default:
      assert(!"Unknown historical period");
   }

   return historicalPeriodStr;
}

CString CHelper::TickFilterToString(
                     eTickFilter tickFilter)
{
   CString tickFilterStr;

   switch (tickFilter)
   {
   case tfAll:
      tickFilterStr = _T("All");
      break;
   case tfAsk:
      tickFilterStr = _T("Ask");
      break;
   case tfAskLow:
      tickFilterStr = _T("AskLow");
      break;
   case tfBid:
      tickFilterStr = _T("Bid");
      break;
   case tfBidHigh:
      tickFilterStr = _T("BidHigh");
      break;
   case tfDefault:
      tickFilterStr = _T("Default");
      break;
   case tfSettlement:
      tickFilterStr = _T("Settlement");
      break;
   case tfTrade:
      tickFilterStr = _T("Trade");
      break;
   default:
      assert(!"Unknown tick filter");
   }

   return tickFilterStr;
}

CString CHelper::ContinuationTypeToString(
                        eTimeSeriesContinuationType continuationType)
{
   CString continuationTypeStr;

   switch (continuationType)
   {
   case tsctNoContinuation:
      continuationTypeStr = _T("NoContinuation");
      break;
   case tsctStandard:
      continuationTypeStr = _T("Standard");
      break;
   case tsctStandardByMonth:
      continuationTypeStr = _T("StandardByMonth");
      break;
   case tsctActive:
      continuationTypeStr = _T("Active");
      break;
   case tsctActiveByMonth:
      continuationTypeStr = _T("ActiveByMonth");
      break;
   case tsctAdjusted:
      continuationTypeStr = _T("Adjusted");
      break;
   case tsctAdjustedByMonth:
      continuationTypeStr = _T("AdjustedByMonth");
      break;
   default:
      assert(!"Unknown continuation type");
   }

   return continuationTypeStr;
}

CString CHelper::SessionFlagToString(
                        eSessionFlag sessionFlag)
{
   CString sessionFlagStr = _T("Undefined");

   if ((sessionFlag & sfDailyFromIntraday) == sfDailyFromIntraday)
   {
      sessionFlagStr = _T("DailyFromIntraday");
   }

   return sessionFlagStr;
}

CString CHelper::DailyBarCloseToString(eDailyBarClose value)
{
   switch (value)
   {
   case dbcDefault: return _T("dbcDefault");
   case dbcLastQuote: return _T("dbcLastQuote");
   case dbcLastQuoteOrSettlement: return _T("dbcLastQuoteOrSettlement");
   case dbcSettlementOrLastQuote: return _T("dbcSettlementOrLastQuote");
   default:
      assert(false);
      return _T("unexpected value");
   }
}